@@ -113,7 +113,7 @@ orderMCMCbase<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,parent
   result$orderscores<-L3
   result$orders<-L4
   result$maxscore<-maxscore
-  result$maxdag<-maxdag
+  result$maxdag<-Matrix(maxdag,sparse=TRUE)
   
   return(result)
 }
