@@ -1,35 +1,3 @@
-orderscoreBase.old<-function(n,scorenodes,scorepositions,parenttable,aliases,numparents,rowmaps,scoretable,scoresmatrices,permy) {
- 
-  orderscores<-vector("double",n)
-  therows<-vector("integer",n)
-  k<-1
-  for (i in scorenodes){
-    position<-scorepositions[k]
-    if (position==n) {  #no parents allowed, i.e. only first row, only first list
-        orderscores[i]<-scoretable[[i]][1,1]
-        therows[i]<-c(2^numparents[i])
-    }
-    else {
-      bannednodes<-permy[1:position]
-      allowednodes<-permy[(position+1):n]
-      bannedpool<-which(aliases[[i]]%in%bannednodes)
-      if (numparents[i]==0||length(bannedpool)==0) { #all parents allowed or no parents in the parent table
-        therows[i]<-c(1)
-      }
-      else {
-        therows[i]<-rowmaps[[i]]$backwards[sum(2^bannedpool)/2+1]
-      }
-        orderscores[i]<-scoresmatrices[[i]][therows[i],1]
-    }
-    k<-k+1
-  }
-  scores<-list()
-  scores$therow<-therows
-  scores$totscores<-orderscores
-  return(scores)
-
-  }
-
 #scores a single order base version (base neighbourhood)
 orderscoreBase<-function(n,scorenodes,scorepositions,parenttable,aliases,numparents,rowmaps,
                          scoretable,scoresmatrices,permy) {
@@ -68,7 +36,7 @@ orderscoreBase<-function(n,scorenodes,scorepositions,parenttable,aliases,numpare
 
 orderscorePlus1<-function(n,scorenodes,scorepositions,parenttable,aliases,numparents,
                           rowmaps,plus1lists,scoretable,scoresmatrices,permy) {
- 
+  
   orderscores<-vector("double",n)
   allowedscorelists<-vector("list",n)
   therows<-vector("integer",n)
@@ -76,9 +44,9 @@ orderscorePlus1<-function(n,scorenodes,scorepositions,parenttable,aliases,numpar
   for (i in scorenodes){
     position<-scorepositions[k]
     if (position==n) {  #no parents allowed, i.e. only first row, only first list
-        orderscores[i]<-scoretable[[i]][[1]][1,1]
-        allowedscorelists[[i]]<-c(1)
-        therows[i]<-c(2^numparents[i])
+      orderscores[i]<-scoretable[[i]][[1]][1,1]
+      allowedscorelists[[i]]<-c(1)
+      therows[i]<-c(2^numparents[i])
     }
     else {
       bannednodes<-permy[1:position]
@@ -90,10 +58,10 @@ orderscorePlus1<-function(n,scorenodes,scorepositions,parenttable,aliases,numpar
       else {
         therows[i]<-rowmaps[[i]]$backwards[sum(2^bannedpool)/2+1]
       }
-        allowedscorelists[[i]]<-c(1,which(plus1lists$parents[[i]]%in%allowednodes)+1)
-        scoresvec<-scoresmatrices[[i]][therows[i],allowedscorelists[[i]]]
-        maxallowed<-max(scoresvec)
-        orderscores[i]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
+      allowedscorelists[[i]]<-c(1,which(plus1lists$parents[[i]]%in%allowednodes)+1)
+      scoresvec<-scoresmatrices[[i]][therows[i],allowedscorelists[[i]]]
+      maxallowed<-max(scoresvec)
+      orderscores[i]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
     }
     k<-k+1
   }
@@ -102,9 +70,9 @@ orderscorePlus1<-function(n,scorenodes,scorepositions,parenttable,aliases,numpar
   scores$allowedlists<-allowedscorelists
   scores$totscores<-orderscores
   return(scores)
-
-
-  }
+  
+  
+}
 
 #returns an order and its BGe/BDe logscore such that is sampled from all orders (according to their scores), obtained via
 #putting a given node in every position from 1 to n with all other nodes fixed  (plus1 neighbourhood)
@@ -122,11 +90,14 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
   allowedlisty<-list()
   therowx<-vector()
   therowy<-vector()
-
+  
   if (positionx>1) {
     rightpart<-permy[-positionx]
     for (i in (positionx-1):1) {
-      nodey<-permy[i]
+      
+      nodey<-permy[i] #node which changes position with nodex
+      
+      #row with the new score of nodex
       if (numparents[x]==0||i==1) {
         therowx[i]<-c(1)
       } else {
@@ -137,12 +108,12 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
           therowx[i]<-rowmaps[[x]]$backwards[sum(2^bannedpool)/2+1]
         }
       }
-
+      
       allowedlistx[[i]]<-c(1,which(plus1lists$parents[[x]]%in%c(permy[(i+1):n],nodey))+1)
       scoresvec<-scoresmatrices[[x]][therowx[i],allowedlistx[[i]]]
       maxallowed<-max(scoresvec)
       vectorx[i]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
-
+      
       newpos<-i+1 #new position of nodey
       if(newpos==n) { #no parents allowed, i.e. only first row, only first list
         vectorall[nodey]<-scoretable[[nodey]][[1]][1,1]
@@ -159,21 +130,21 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
         if (newpos==n) {allowedlisty[[nodey]]<-c(1)} else {
           allowedlisty[[nodey]]<-c(1,which(plus1lists$parents[[nodey]]%in%rightpart[(newpos):(n-1)])+1)
         }
-
+        
         scoresvec<-scoresmatrices[[nodey]][therowy[nodey],allowedlisty[[nodey]]]
         maxallowed<-max(scoresvec)
         vectorall[nodey]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
       }
-
+      
       totalall[i]<-totalall[i+1]-vectorx[i+1]+vectorx[i]-base[nodey]+vectorall[nodey]
     }
   }
-
+  
   if (positionx < nsmall) {
-
+    
     for (i in (positionx+1):nsmall) {
       nodey<-permy[i]
-
+      
       if (numparents[x]==0) { #there is only 1 row in the score table
         therowx[i]<-c(1)
       } else if (i==n) { #no parents allowed, i.e. only first row, only first list
@@ -190,12 +161,12 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
       if (i==n) { allowedlistx[[i]]<-c(1)} else {
         allowedlistx[[i]]<-c(1,which(plus1lists$parents[[x]]%in%permy[(i+1):n])+1)
       }
-
+      
       scoresvec<-scoresmatrices[[x]][therowx[i],allowedlistx[[i]]]
       maxallowed<-max(scoresvec)
       vectorx[i]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
-
-
+      
+      
       newpos<-i-1
       if (newpos==1) {
         therowy[nodey]<-c(1)
@@ -207,21 +178,21 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
           therowy[nodey]<-rowmaps[[nodey]]$backwards[sum(2^bannedpool)/2+1]
         }
       }
-
+      
       allowedlisty[[nodey]]<-c(1,which(plus1lists$parents[[nodey]]%in%c(permy[i:n],x))+1)
       scoresvec<-scoresmatrices[[nodey]][therowy[nodey],allowedlisty[[nodey]]]
       maxallowed<-max(scoresvec)
       vectorall[nodey]<-maxallowed+log(sum(exp(scoresvec-maxallowed)))
-
+      
       totalall[i]<-totalall[i-1]-vectorx[i-1]+vectorx[i]-base[nodey]+vectorall[nodey]
     }
   }
-
+  
   totalmax<-max(totalall)
   allscore<-totalmax+log(sum(exp(totalall-totalmax)))
   maxi<-sample.int(nsmall,1,prob=exp(totalall-allscore))
   res<-list()
-
+  
   if (maxi==positionx) {
     res$score<-currentscore
     res$order<-permy
@@ -254,9 +225,9 @@ positionscorePlus1<-function(n,nsmall,currentscore,positionx,permy,aliases,rowma
     res$tot<-totalall[maxi]
     return(res)
   }
-
-
-  }
+  
+  
+}
 
 #returns an order and its BGe/BDe logscore such that is sampled from all orders (according to their scores), obtained via
 #putting a given node in every position from 1 to n with all other nodes fixed  (plus1 neighbourhood)
@@ -391,5 +362,5 @@ positionscorebase<-function(n,nsmall,currentscore,positionx,permy,aliases,rowmap
     res$tot<-totalall[maxi]
     return(res)
   }
-
-  }
+  
+}
